==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/kvmvm/data_kvmvm_list/main.tf <==
/*
Пример использования
Получение данных об списке compute (виртуальных машин)
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_kvmvm_list" "compute_list" {
  #фильтр по id ВМ
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени ВМ
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для получения списка ВМ
  #опциональный параметр 
  #тип - целое число
  #account_id = 11111

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #rg_name = "test"

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - целое число
  #rg_id = 100

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "STOPPED"

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #фильтр по ip
  #опциональный параметр
  #тип - строка
  #ip_address = "test"

  #фильтр по имени extnet
  #опциональный параметр
  #тип - строка
  #extnet_name = "test"

  #фильтр по id extnet
  #опциональный параметр
  #тип - целое число
  #extnet_id = 100

  #флаг включения в результат удаленных балансироващиков нагрузки
  #опциональный параметр
  #тип - булев
  #значение по-умолчанию - false
  #если не задан - выводятся все доступные неудаленные балансировщики
  #includedeleted = true

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 1
}

output "output" {
  value = data.dynamix_kvmvm_list.compute_list
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/kvmvm/data_kvmvm_list/main.tf <==
/*
Пример использования
Получение данных об списке compute (виртуальных машин)
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_kvmvm_list" "compute_list" {
  #фильтр по id ВМ
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени ВМ
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для получения списка ВМ
  #опциональный параметр 
  #тип - целое число
  #account_id = 11111

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #rg_name = "test"

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - целое число
  #rg_id = 100

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "STOPPED"

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #фильтр по ip
  #опциональный параметр
  #тип - строка
  #ip_address = "test"

  #фильтр по имени extnet
  #опциональный параметр
  #тип - строка
  #extnet_name = "test"

  #фильтр по id extnet
  #опциональный параметр
  #тип - целое число
  #extnet_id = 100

  #флаг включения в результат удаленных балансироващиков нагрузки
  #опциональный параметр
  #тип - булев
  #значение по-умолчанию - false
  #если не задан - выводятся все доступные неудаленные балансировщики
  #includedeleted = true

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 1
}

output "output" {
  value = data.dynamix_kvmvm_list.compute_list
}
